==> microfrontends-0.0.10.tar.gz: test/state_container_provider_test.dart <==
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_test/flutter_test.dart';

import 'package:microfrontends/microfrontends.dart';
import 'package:microfrontends/src/state_container_provider.dart';

import 'mock/countdown_container.dart';
import 'mock/mock_state.dart';
import 'mock/state_container_provider_app.dart';
import 'mock/mock_container.dart';
import 'mock/string_container.dart';

String groupTitle = 'StateContainerProvider';

void main() {
  final ctr = MockContainer();

  testWidgets('provides queries to children', (tester) async {
    await tester.pumpWidget(
      StateContainerProviderApp(
        container: ctr,
        builder: (context) {
          final v = context.query<int>()!;
          return Text(v.toString());
        },
      ),
    );

    final textFinder = find.text('0');
    expect(textFinder, findsOneWidget);
  });

  testWidgets('provides mutations to children', (tester) async {
    await tester.pumpWidget(
      StateContainerProviderApp(
        container: ctr,
        builder: (context) {
          SchedulerBinding.instance!.addPostFrameCallback((timeStamp) {
            context.mutation(Increment());
          });

          return SizedBox();
        },
      ),
    );

    SchedulerBinding.instance!.addPostFrameCallback((timeStamp) {
      expect(MockContainer().state.value, equals(1));
    });
  });

  testWidgets('provides subscriptions to children', (tester) async {
    await tester.pumpWidget(
      StateContainerProviderApp(
        container: ctr,
        builder: (context) {
          return context.subscribe<int>(builder: (context, value, _) {
            return Text(value.toString());
          });
        },
      ),
    );

    expect(find.text('0'), findsOneWidget);

    MockContainer().state = MockState(1);
    await tester.pump();
    expect(find.text('1'), findsOneWidget);
  });

  testWidgets('calls init stream', (tester) async {
    final count = 5;
    final duration = Duration(milliseconds: 1);

    await tester.pumpWidget(
      StateContainerProviderApp(
        builder: (context) {
          return context.subscribe<MockState>(
            builder: (context, value, _) {
              return Text(value.value.toString());
            },
          );
        },
        container: CountdownContainer(count, duration),
      ),
    );

    for (int i = 0; i < count; i++) {
      expect(find.text(i.toString()), findsOneWidget);
      await tester.pump(duration);
    }
  });

  testWidgets('inherits resolvers from parent containers', (tester) async {
    final string = 'test string';

    await tester.pumpWidget(
      StateContainerProviderApp(
        builder: (context) {
          return StateContainerProvider(
            container: StringContainer(string),
            child: Builder(
              builder: (context) {
                final l = context.query<Length>()!;
                final v = context.query<int>()!;

                return Column(
                  children: [
                    Text('int: $v'),
                    Text('string length: ${l.payload}'),
                  ],
                );
              },
            ),
          );
        },
        container: ctr,
      ),
    );

    await tester.pump();

    expect(find.text('int: 0'), findsOneWidget);
    expect(find.text('string length: ${string.length}'), findsOneWidget);
  });

  testWidgets('clears unmounted listener widgets', (tester) async {
    int effectCalledCount = 0;

    await tester.pumpWidget(
      StateContainerProviderApp(
        builder: (context) {
          return context.subscribe<int>(builder: (context, v, _) {
            if (v < 2) {
              return Builder(builder: (context) {
                Effect<int>((_, __) {
                  effectCalledCount++;
                }).bind(context);

                return Text('subscriber');
              });
            }

            return Text(v.toString());
          });
        },
        container: ctr,
      ),
    );

    expect(find.text('subscriber'), findsOneWidget);

    ctr.state = MockState(1);
    tester.binding.scheduleFrame();
    await tester.pump();

    ctr.state = MockState(2);
    tester.binding.scheduleFrame();
    await tester.pump();

    expect(find.text('subscriber'), findsNothing);

    ctr.state = MockState(3);
    tester.binding.scheduleFrame();
    await tester.pump();

    expect(effectCalledCount, equals(1));
  });
}

==> microfrontends-0.0.13.tar.gz: test/state_container_provider_test.dart <==
import 'package:flutter/scheduler.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_test/flutter_test.dart';

import 'package:microfrontends/microfrontends.dart';
import 'package:microfrontends/src/state_container_provider.dart';

import 'mock/countdown_container.dart';
import 'mock/mock_state.dart';
import 'mock/state_container_provider_app.dart';
import 'mock/mock_container.dart';
import 'mock/string_container.dart';

String groupTitle = 'StateContainerProvider';

void main() {
  final ctr = MockContainer();

  testWidgets('provides queries to children', (tester) async {
    await tester.pumpWidget(
      StateContainerProviderApp(
        container: ctr,
        builder: (context) {
          final v = context.query<int>()!;
          return Text(v.toString());
        },
      ),
    );

    final textFinder = find.text('0');
    expect(textFinder, findsOneWidget);
  });

  testWidgets('provides mutations to children', (tester) async {
    await tester.pumpWidget(
      StateContainerProviderApp(
        container: ctr,
        builder: (context) {
          SchedulerBinding.instance!.addPostFrameCallback((timeStamp) {
            context.mutation(Increment());
          });

          return SizedBox();
        },
      ),
    );

    SchedulerBinding.instance!.addPostFrameCallback((timeStamp) {
      expect(MockContainer().state.value, equals(1));
    });
  });

  testWidgets('provides subscriptions to children', (tester) async {
    await tester.pumpWidget(
      StateContainerProviderApp(
        container: ctr,
        builder: (context) {
          return QueryBuilder<int>(builder: (context, value, _) {
            return Text(value.toString());
          });
        },
      ),
    );

    expect(find.text('0'), findsOneWidget);

    MockContainer().state = MockState(1);
    await tester.pump();
    expect(find.text('1'), findsOneWidget);
  });

  testWidgets('calls init stream', (tester) async {
    final count = 5;
    final duration = Duration(milliseconds: 1);

    await tester.pumpWidget(
      StateContainerProviderApp(
        builder: (context) {
          return QueryBuilder<MockState>(
            builder: (context, value, _) {
              return Text(value.value.toString());
            },
          );
        },
        container: CountdownContainer(count, duration),
      ),
    );

    for (int i = 0; i < count; i++) {
      expect(find.text(i.toString()), findsOneWidget);
      await tester.pump(duration);
    }
  });

  testWidgets('inherits resolvers from parent containers', (tester) async {
    final string = 'test string';

    await tester.pumpWidget(
      StateContainerProviderApp(
        builder: (context) {
          return StateContainerProvider(
            container: StringContainer(string),
            child: Builder(
              builder: (context) {
                final l = context.query<Length>()!;
                final v = context.query<int>()!;

                return Column(
                  children: [
                    Text('int: $v'),
                    Text('string length: ${l.payload}'),
                  ],
                );
              },
            ),
          );
        },
        container: ctr,
      ),
    );

    await tester.pump();

    expect(find.text('int: 0'), findsOneWidget);
    expect(find.text('string length: ${string.length}'), findsOneWidget);
  });

  testWidgets('clears unmounted listener widgets', (tester) async {
    int effectCalledCount = 0;

    await tester.pumpWidget(
      StateContainerProviderApp(
        builder: (context) {
          return QueryBuilder<int>(builder: (context, v, _) {
            if (v < 2) {
              return Builder(builder: (context) {
                Effect<int>((_, __) {
                  effectCalledCount++;
                }).bind(context);

                return Text('subscriber');
              });
            }

            return Text(v.toString());
          });
        },
        container: ctr,
      ),
    );

    expect(find.text('subscriber'), findsOneWidget);

    ctr.state = MockState(1);
    tester.binding.scheduleFrame();
    await tester.pump();

    ctr.state = MockState(2);
    tester.binding.scheduleFrame();
    await tester.pump();

    expect(find.text('subscriber'), findsNothing);

    ctr.state = MockState(3);
    tester.binding.scheduleFrame();
    await tester.pump();

    expect(effectCalledCount, equals(1));
  });
}
